@@ -9,7 +9,7 @@ from .jc_types import ParserInfoType, JSONDictType
 from jc import appdirs
 
 
-__version__ = '1.23.4'
+__version__ = '1.23.6'
 
 parsers: List[str] = [
     'acpi',
@@ -58,6 +58,7 @@ parsers: List[str] = [
     'hashsum',
     'hciconfig',
     'history',
+    'host',
     'hosts',
     'id',
     'ifconfig',
@@ -79,6 +80,7 @@ parsers: List[str] = [
     'ls',
     'ls-s',
     'lsattr',
+    'lsb-release',
     'lsblk',
     'lsmod',
     'lsof',
@@ -91,9 +93,11 @@ parsers: List[str] = [
     'mpstat-s',
     'netstat',
     'nmcli',
+    'nsd-control',
     'ntpq',
     'openvpn',
     'os-prober',
+    'os-release',
     'passwd',
     'pci-ids',
     'pgpass',
